@@ -17,9 +17,6 @@ class Index extends BaseController {
      * @return void
      */
     public function home() {
-        // check login
-        $this->authentication();
-
         // parse params
         $options = [];
         if (\F3::get('homepage') != '') {
@@ -33,13 +30,15 @@ class Index extends BaseController {
 
         if (!isset($options['ajax'])) {
             // show as full html page
-            $this->view->publicMode = \F3::get('auth')->isLoggedin() !== true && \F3::get('public') == 1;
-            $this->view->loggedin = \F3::get('auth')->isLoggedin() === true;
+            $this->view->publicMode = \F3::get('public') == 1;
+            $this->view->authEnabled = \F3::get('auth')->enabled() === true;
             echo $this->view->render('templates/home.phtml');
 
             return;
         }
 
+        $this->needsLoggedInOrPublicMode();
+
         // get search param
         if (isset($options['search']) && strlen($options['search']) > 0) {
             $this->view->search = $options['search'];
@@ -103,49 +102,11 @@ class Index extends BaseController {
      * @return void
      */
     public function password() {
-        $this->view = new \helpers\View();
         $this->view->password = true;
         if (isset($_POST['password'])) {
             $this->view->hash = hash('sha512', \F3::get('salt') . $_POST['password']);
         }
-        echo $this->view->render('templates/login.phtml');
-    }
-
-    /**
-     * check and show login/logout
-     * html
-     *
-     * @return void
-     */
-    private function authentication() {
-        // logout
-        if (isset($_GET['logout'])) {
-            \F3::get('auth')->logout();
-            \F3::reroute($this->view->base);
-        }
-
-        // login
-        $loginRequired = \F3::get('public') != 1 && \F3::get('auth')->isLoggedin() !== true;
-        $showLoginForm = isset($_GET['login']) || $loginRequired;
-        if ($showLoginForm) {
-            // authenticate?
-            if (count($_POST) > 0) {
-                if (!isset($_POST['username'])) {
-                    $this->view->error = 'no username given';
-                } elseif (!isset($_POST['password'])) {
-                    $this->view->error = 'no password given';
-                } elseif (!\F3::get('auth')->login($_POST['username'], $_POST['password'])) {
-                    $this->view->error = 'invalid username/password';
-                }
-            }
-
-            // show login
-            if (count($_POST) === 0 || isset($this->view->error)) {
-                die($this->view->render('templates/login.phtml'));
-            } else {
-                \F3::reroute($this->view->base);
-            }
-        }
+        echo $this->view->render('templates/hashpassword.phtml');
     }
 
     /**
@@ -155,18 +116,38 @@ class Index extends BaseController {
      * @return void
      */
     public function login() {
-        $view = new \helpers\View();
-        $username = isset($_REQUEST['username']) ? $_REQUEST['username'] : '';
-        $password = isset($_REQUEST['password']) ? $_REQUEST['password'] : '';
+        $error = null;
+
+        if (isset($_REQUEST['username'])) {
+            $username = $_REQUEST['username'];
+        } else {
+            $username = '';
+            $error = 'no username given';
+        }
+
+        if (isset($_REQUEST['password'])) {
+            $password = $_REQUEST['password'];
+        } else {
+            $password = '';
+            $error = 'no password given';
+        }
+
+        if ($error !== null) {
+            $this->view->jsonError([
+                'success' => false,
+                'error' => $error
+            ]);
+        }
 
         if (\F3::get('auth')->login($username, $password)) {
-            $view->jsonSuccess([
+            $this->view->jsonSuccess([
                 'success' => true
             ]);
         }
 
-        $view->jsonSuccess([
-            'success' => false
+        $this->view->jsonSuccess([
+            'success' => false,
+            'error' => \F3::get('lang_login_invalid_credentials'),
         ]);
     }
 
@@ -177,9 +158,8 @@ class Index extends BaseController {
      * @return void
      */
     public function logout() {
-        $view = new \helpers\View();
         \F3::get('auth')->logout();
-        $view->jsonSuccess([
+        $this->view->jsonSuccess([
             'success' => true
         ]);
     }
@@ -221,30 +201,24 @@ class Index extends BaseController {
     /**
      * load items
      *
-     * @return html with items
+     * @return string html with items
      */
     private function loadItems($options, $tags) {
-        $tagColors = $this->convertTagsToAssocArray($tags);
         $itemDao = new \daos\Items();
         $itemsHtml = '';
 
         $firstPage = $options['offset'] == 0
-            && $options['offset_from_id'] == ''
-            && $options['offset_from_datetime'] == '';
+            && $options['fromId'] == ''
+            && $options['fromDatetime'] == '';
         if ($options['source'] && $this->allowedToUpdate() && $firstPage) {
             $itemsHtml = '<button type="button" id="refresh-source" class="refresh-source">' . \F3::get('lang_source_refresh') . '</button>';
         }
 
+        $tagsController = new \controllers\Tags();
         foreach ($itemDao->get($options) as $item) {
             // parse tags and assign tag colors
-            $itemsTags = explode(',', $item['tags']);
-            $item['tags'] = [];
-            foreach ($itemsTags as $tag) {
-                $tag = trim($tag);
-                if (strlen($tag) > 0 && isset($tagColors[$tag])) {
-                    $item['tags'][$tag] = $tagColors[$tag];
-                }
-            }
+            $itemTags = explode(',', $item['tags']);
+            $item['tags'] = $tagsController->tagsAddColors($itemTags, $tags);
 
             $this->view->item = $item;
             $itemsHtml .= $this->view->render('templates/item.phtml');
@@ -255,21 +229,4 @@ class Index extends BaseController {
             'hasMore' => $itemDao->hasMore()
         ];
     }
-
-    /**
-     * return tag => color array
-     *
-     * @param array $tags
-     *
-     * @return tag color array
-     */
-    private function convertTagsToAssocArray($tags) {
-        $assocTags = [];
-        foreach ($tags as $tag) {
-            $assocTags[$tag['tag']]['backColor'] = $tag['color'];
-            $assocTags[$tag['tag']]['foreColor'] = \helpers\Color::colorByBrightness($tag['color']);
-        }
-
-        return $assocTags;
-    }
 }
