@@ -206,6 +206,27 @@ class Database {
                         'INSERT INTO version (version) VALUES (10);'
                     ]);
                 }
+                if (strnatcmp($version, '11') < 0) {
+                    \F3::get('db')->exec([
+                        'DROP TRIGGER update_updatetime_trigger ON items',
+                        'ALTER TABLE items ADD lastseen TIMESTAMP(0) WITH TIME ZONE NOT NULL DEFAULT NOW()',
+                        'CREATE TRIGGER update_updatetime_trigger
+                            BEFORE UPDATE ON items FOR EACH ROW
+                            WHEN (
+                                OLD.unread IS DISTINCT FROM NEW.unread OR
+                                OLD.starred IS DISTINCT FROM NEW.starred
+                            )
+                            EXECUTE PROCEDURE update_updatetime_procedure();',
+                        'INSERT INTO version (version) VALUES (11);'
+                    ]);
+                }
+                if (strnatcmp($version, '12') < 0) {
+                    \F3::get('db')->exec([
+                        'UPDATE items SET updatetime = datetime WHERE updatetime IS NULL',
+                        'ALTER TABLE items ALTER COLUMN updatetime SET NOT NULL',
+                        'INSERT INTO version (version) VALUES (12)'
+                    ]);
+                }
             }
 
             // just initialize once
@@ -216,15 +237,13 @@ class Database {
     /**
      * optimize database by the database's own optimize statement
      *
-     * Note that for pg, for full optimization you'd run "vacuum full analyze {table}".  This does require
-     * an exclusive lock on the table though and so this is probably best run offline during scheduled
-     * downtime.  See https://www.postgresql.org/docs/9.6/static/sql-vacuum.html for more information
-     * (particularly the notes in the footer of that page leading to further DBA-related info e.g. the
-     * autovacuum daemon).
+     * Note that for pg, no optimization is needed because autovacuuming is
+     * enabled by default.
+     * See
+     * https://www.postgresql.org/docs/9.1/static/runtime-config-autovacuum.html
      *
      * @return  void
      */
     public function optimize() {
-        \F3::get('db')->exec('VACUUM ANALYZE');
     }
 }
