@@ -1,15 +1,15 @@
-<?PHP
+<?php
 
 namespace daos\sqlite;
 
 /**
  * Class for accessing persistent saved items -- sqlite
  *
- * @package    daos
  * @copyright  Copyright (c) Harald Lapp <harald.lapp@gmail.com>
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Harald Lapp <harald.lapp@gmail.com>
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 // class Items extends Database {
-class Items extends \daos\mysql\Items { }
+class Items extends \daos\mysql\Items {
+}
