@@ -1,14 +1,14 @@
-<?PHP
+<?php
 
 namespace daos\sqlite;
 
 /**
  * Class for accessing persistent saved sources -- mysql
  *
- * @package    daos
  * @copyright  Copyright (c) Harald Lapp <harald.lapp@gmail.com>
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Harald Lapp <harald.lapp@gmail.com>
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
-class Sources extends \daos\mysql\Sources { }
+class Sources extends \daos\mysql\Sources {
+}
