@@ -66,18 +66,6 @@ class Authentication {
         return strlen(trim(\F3::get('username'))) != 0 && strlen(trim(\F3::get('password'))) != 0;
     }
 
-    /**
-     * login user
-     *
-     * @param string $username
-     * @param string $password
-     *
-     * @return bool
-     */
-    public function loginWithoutUser() {
-        $this->loggedin = true;
-    }
-
     /**
      * login user
      *
