@@ -11,41 +11,18 @@ if ($lang != '0' && $lang != '') {
 // init authentication
 $f3->set('auth', new \helpers\Authentication());
 
+/** @var stdClass JS client package manifest */
+$clientPackage = json_decode(file_get_contents(__DIR__ . '/public/package.json'));
+
 // define js files
-$js = [
-    'public/js/jquery-2.1.1.min.js',
-    'public/js/jquery-ui.js',
-    'public/js/jquery.mCustomScrollbar.min.js',
-    'public/js/jquery.mousewheel.min.js',
-    'public/js/lazy-image-loader.js',
-    'public/js/spectrum.js',
-    'public/js/jquery.hotkeys.js',
-    'public/js/selfoss-base.js',
-    'public/js/selfoss-shares.js',
-    'public/js/selfoss-db.js',
-    'public/js/selfoss-ui.js',
-    'public/js/selfoss-events.js',
-    'public/js/selfoss-events-navigation.js',
-    'public/js/selfoss-events-search.js',
-    'public/js/selfoss-events-entries.js',
-    'public/js/selfoss-events-entriestoolbar.js',
-    'public/js/selfoss-events-sources.js',
-    'public/js/selfoss-shortcuts.js',
-    'public/js/jquery.fancybox.pack.js'
-];
+$js = $clientPackage->extra->requiredFiles->js;
 if (file_exists('user.js')) {
     $js[] = 'user.js';
 }
 $f3->set('js', $js);
 
 // define css files
-$css = [
-    'public/css/jquery.mCustomScrollbar.css',
-    'public/css/jquery.fancybox.css',
-    'public/css/spectrum.css',
-    'public/css/reset.css',
-    'public/css/style.css'
-];
+$css = $clientPackage->extra->requiredFiles->css;
 if (file_exists('user.css')) {
     $css[] = 'user.css';
 }
@@ -55,10 +32,10 @@ $f3->set('css', $css);
 
 // all users
 $f3->route('GET /', 'controllers\Index->home'); // html
-$f3->route('POST /', 'controllers\Index->home'); // html
 $f3->route('GET /password', 'controllers\Index->password'); // html
 $f3->route('POST /password', 'controllers\Index->password'); // html
 $f3->route('GET /login', 'controllers\Index->login'); // json
+$f3->route('POST /login', 'controllers\Index->login'); // json
 $f3->route('GET /logout', 'controllers\Index->logout'); // json
 $f3->route('GET /update', 'controllers\Index->update'); // text
 $f3->route('GET /badge', 'controllers\Index->badge'); // xml
