@@ -1,41 +1,28 @@
-<?PHP 
+<?php
 
 namespace spouts\deviantart;
 
 /**
  * Spout for fetching an rss feed
  *
- * @package    spouts
- * @subpackage rss
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class dailydeviations extends \spouts\rss\images {
-
-    /**
-     * name of source
-     *
-     * @var string
-     */
+    /** @var string name of source */
     public $name = 'deviantART - daily deviations';
-    
-    
-    /**
-     * description of this source type
-     *
-     * @var string
-     */
+
+    /** @var string description of this source type */
     public $description = 'daily deviations of deviantART';
-    
-    
+
     /**
      * config params
      * array of arrays with name, type, default value, required, validation type
      *
      * - Values for type: text, password, checkbox
      * - Values for validation: alpha, email, numeric, int, alnum, notempty
-     * 
+     *
      * e.g.
      * array(
      *   "id" => array(
@@ -51,28 +38,28 @@ class dailydeviations extends \spouts\rss\images {
      * @var bool|mixed
      */
     public $params = false;
-    
-    
+
     /**
      * loads content for given source
      * I supress all Warnings of SimplePie for ensuring
      * working plugin in PHP Strict mode
      *
-     * @return void
      * @param mixed $params the params of this source
+     *
+     * @return void
      */
     public function load($params) {
-        parent::load(array( "url" => $this->getXmlUrl()));
+        parent::load(['url' => $this->getXmlUrl()]);
     }
 
-
     /**
      * returns the xml feed url for the source
      *
-     * @return string url as xml
      * @param mixed $params params for the source
+     *
+     * @return string url as xml
      */
     public function getXmlUrl($params = null) {
-        return 'http://backend.deviantart.com/rss.xml?q=special%3Add&type=deviation&offset=0';
+        return 'https://backend.deviantart.com/rss.xml?q=special%3Add&type=deviation&offset=0';
     }
 }
