@@ -1,36 +1,22 @@
-<?PHP 
+<?php
 
 namespace spouts\rss;
 
 /**
  * Plugin for fetching the news and cleaning the content with instapaper.com
  *
- * @package    plugins
- * @subpackage rss
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  * @author     Daniel Seither <post@tiwoc.de>
  */
 class instapaper extends feed {
-
-
-    /**
-     * name of spout
-     *
-     * @var string
-     */
+    /** @var string name of spout */
     public $name = 'RSS Feed (with instapaper)';
-    
-    
-    /**
-     * description of this source type
-     *
-     * @var string
-     */
+
+    /** @var string description of this source type */
     public $description = 'This feed cleaning the content with instapaper.com';
-    
-    
+
     /**
      * config params
      * array of arrays with name, type, default value, required, validation type
@@ -41,7 +27,7 @@ class instapaper extends feed {
      * When type is "select", a new entry "values" must be supplied, holding
      * key/value pairs of internal names (key) and displayed labels (value).
      * See /spouts/rss/heise for an example.
-     * 
+     *
      * e.g.
      * array(
      *   "id" => array(
@@ -56,27 +42,27 @@ class instapaper extends feed {
      *
      * @var bool|mixed
      */
-    public $params = array(
-        "url" => array(
-            "title"      => "URL",
-            "type"       => "url",
-            "default"    => "",
-            "required"   => true,
-            "validation" => array("notempty")
-        )
-    );
-  
+    public $params = [
+        'url' => [
+            'title' => 'URL',
+            'type' => 'url',
+            'default' => '',
+            'required' => true,
+            'validation' => ['notempty']
+        ]
+    ];
+
     /**
      * loads content for given source
      *
-     * @return void
      * @param string $url
+     *
+     * @return void
      */
     public function load($params) {
-        parent::load(array( 'url' => $params['url']) );
+        parent::load(['url' => $params['url']]);
     }
-    
-    
+
     /**
      * returns the content of this item
      *
@@ -84,32 +70,35 @@ class instapaper extends feed {
      */
     public function getContent() {
         $contentFromInstapaper = $this->fetchFromInstapaper(parent::getLink());
-        if($contentFromInstapaper===false)
-            return "instapaper parse error <br />" . parent::getContent();
+        if ($contentFromInstapaper === false) {
+            return 'instapaper parse error <br />' . parent::getContent();
+        }
+
         return $contentFromInstapaper;
     }
-    
-    
+
     /**
      * fetch content from instapaper.com
      *
      * @author janeczku @github
+     *
      * @return string content
      */
     private function fetchFromInstapaper($url) {
-        if (function_exists('curl_init') && !ini_get("open_basedir")) {
-            $content = $this->file_get_contents_curl("https://www.instapaper.com/text?u=" . urlencode($url));
-        }
-        else {
-            $content = @file_get_contents("https://www.instapaper.com/text?u=" . urlencode($url));
+        if (function_exists('curl_init') && !ini_get('open_basedir')) {
+            $content = $this->file_get_contents_curl('https://www.instapaper.com/text?u=' . urlencode($url));
+        } else {
+            $content = @file_get_contents('https://www.instapaper.com/text?u=' . urlencode($url));
         }
         $dom = new \DOMDocument();
         @$dom->loadHTML($content);
-        if (!$dom)
+        if (!$dom) {
             return false;
+        }
         $xpath = new \DOMXPath($dom);
         $elements = $xpath->query("//div[@id='story']");
         $content = $dom->saveXML($elements->item(0), LIBXML_NOEMPTYTAG);
+
         return $content;
     }
 
@@ -118,11 +107,10 @@ class instapaper extends feed {
         curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 15);
         curl_setopt($ch, CURLOPT_TIMEOUT, 15);
         curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
-        curl_setopt($ch, CURLOPT_URL, $url);   
+        curl_setopt($ch, CURLOPT_URL, $url);
         $data = @curl_exec($ch);
         curl_close($ch);
-     
+
         return $data;
     }
-
 }
